@@ -115,11 +115,12 @@ def wi():
     return wi
 
 
-def wr_index():
+def wr_index(code=13):
     """
     東京の今日の天気を，インデックスで返す
     1:晴れ，2:曇り，3:雨，4:雪
     """
+    d = get_wf_json(code)
     return int(d[0]["timeSeries"][0]["areas"][0]["weatherCodes"][0][0])
 
 
